@@ -164,6 +164,10 @@ class LibraryItem:
             return
 
         codec = self._get_codec(quality)
+        if codec is None:
+            secho(f"{self.full_title} is not downloadable. No AAX codec found.",
+                  fg="red")
+            return
         url = self._build_aax_request_url(codec)
         if client is None:
             assert self._auth is not None
@@ -184,6 +188,10 @@ class LibraryItem:
             return
 
         codec = self._get_codec(quality)
+        if codec is None:
+            secho(f"{self.full_title} is not downloadable. No AAX codec found.",
+                  fg="red")
+            return
         url = self._build_aax_request_url(codec)
         if client is None:
             assert self._auth is not None
@@ -312,7 +320,7 @@ class LibraryItem:
 
 class Library:
     def __init__(self,
-                 data: dict,
+                 data: Union[dict, list],
                  locale: Optional[Locale] = None,
                  country_code: Optional[str] = None,
                  auth: Optional[Authenticator] = None):
@@ -326,8 +334,11 @@ class Library:
         locale = Locale(country_code) if country_code else locale
         self._locale = locale or auth.locale
         self._auth = auth
+
+        if isinstance(data, dict):
+            data = data.get("items", data)
         self._data = [LibraryItem(i, locale=self._locale, auth=self._auth)
-                      for i in data.get("items", data)]
+                      for i in data]
 
     def __iter__(self):
         return iter(self._data)
@@ -338,9 +349,28 @@ class Library:
                      locale: Optional[Locale] = None,
                      country_code: Optional[str] = None,
                      close_session: bool = False,
-                     timeout: int = 10,
                      **request_params):
 
+        def fetch_library(params):
+            entire_lib = False
+            if "page" not in params and "num_results" not in params:
+                entire_lib = True
+                params["page"] = 1
+                num_results = 1000
+                params["num_results"] = num_results
+
+            library = []
+            while True:
+                r = api_client.get(
+                    "library", params=params)
+                items = r["items"]
+                len_items = len(items)
+                library.extend(items)
+                if not entire_lib or len_items < num_results:
+                    break
+                params["page"] += 1
+            return library
+
         if locale is not None and country_code is not None:
             raise ValueError("Locale and country_code provided. Expected only "
                              "one of them.")
@@ -351,11 +381,9 @@ class Library:
 
         if close_session:
             with api_client:
-                resp = api_client.get(
-                    "library", params=request_params, timeout=timeout)
+                resp = fetch_library(request_params)
         else:
-            resp = api_client.get(
-                "library", params=request_params, timeout=timeout)
+            resp = fetch_library(request_params)
 
         return cls(resp, auth=api_client.auth)
 
@@ -365,9 +393,28 @@ class Library:
                             locale: Optional[Locale] = None,
                             country_code: Optional[str] = None,
                             close_session: bool = False,
-                            timeout: int = 10,
                             **request_params):
 
+        async def fetch_library(params):
+            entire_lib = False
+            if "page" not in params and "num_results" not in params:
+                entire_lib = True
+                params["page"] = 1
+                num_results = 1000
+                params["num_results"] = num_results
+
+            library = []
+            while True:
+                r = await api_client.get(
+                    "library", params=params)
+                items = r["items"]
+                len_items = len(items)
+                library.extend(items)
+                if not entire_lib or len_items < num_results:
+                    break
+                params["page"] += 1
+            return library
+
         if locale is not None and country_code is not None:
             raise ValueError("Locale and country_code provided. Expected only "
                              "one of them.")
@@ -378,11 +425,9 @@ class Library:
 
         if close_session:
             async with api_client:
-                resp = await api_client.get(
-                    "library", params=request_params, timeout=timeout)
+                resp = await fetch_library(request_params)
         else:
-            resp = await api_client.get(
-                "library", params=request_params, timeout=timeout)
+            resp = await fetch_library(request_params)
 
         return cls(resp, auth=api_client.auth)
 
